bool reqUserLogin(const dict &req, int reqid);

bool reqUserLogout(const dict &req, int reqid);

bool reqSafeVerify(const dict &req, int reqid);

bool reqVerifyCode(const dict &req, int reqid);

bool reqSetVerifyQA(const dict &req, int reqid);

bool reqGetQuestion(const dict &req, int reqid);

bool reqOrderInsert(const dict &req, int reqid);

bool reqOrderModify(const dict &req, int reqid);

bool reqOrderCancel(const dict &req, int reqid);

bool reqPasswordUpdate(const dict &req, int reqid);

bool reqQryOrder(const dict &req, int reqid);

bool reqQryTrade(const dict &req, int reqid);

bool reqQryCapital(const dict &req, int reqid);

bool reqQryVersion(const dict &req, int reqid);

bool reqQryCurrency(const dict &req, int reqid);

bool reqQryExchange(const dict &req, int reqid);

bool reqQryPosition(const dict &req, int reqid);

bool reqQryStrategy(const dict &req, int reqid);

bool reqQryCommodity(const dict &req, int reqid);

bool reqQryInstrument(const dict &req, int reqid);

bool reqQryExchangeTime(const dict &req, int reqid);

bool reqQryCommodityTime(const dict &req, int reqid);

bool reqQryTotalPosition(const dict &req, int reqid);

bool reqQryStrategyDetail(const dict &req, int reqid);

