DA_STR_SIZE = 256
TRADE_MAX_NUM_ONE_PAGE = (5000)
MAX_BROKER = 4096
DAAPI_VERSION = "1.18.2.0"
MAX_SUB_COUNT = 20
DAF_TYPE_Stock = 'S'
DAF_TYPE_Future = 'D'
DAF_TYPE_Unknown = 0
DAF_SUB_Append = '1'
DAF_SUB_Replace = '2'
DAF_SUB_Unsubcribe = '3'
DAF_SUB_UnsubcribeAll = '4'
DAF_Market_Full = 'Z'
DAF_Market_Fill = 'Y'
EMPTY_STRING = ""
DERIVATIVE_BID = "1"
DERIVATIVE_ASK = "2"
DERIVATIVE_OPEN_POS_FLAG = "1"
DERIVATIVE_CLOSE_POS_FLAG = "2"
DERIVATIVE_LIMIT_ORDER = "1"
DERIVATIVE_MARKET_ORDER = "2"
DERIVATIVE_LIMIT_STOP_ORDER = "3"
DERIVATIVE_STOP_LOSS_ORDER = "4"
DERIVATIVE_TDY_TIF = "1"
DERIVATIVE_GTC_TIF = "2"
DERIVATIVE_OPG_TIF = "3"
DERIVATIVE_IOC_TIF = "4"
DERIVATIVE_FOK_TIF = "5"
DERIVATIVE_GTD_TIF = "6"
DERIVATIVE_ATC_TIF = "7"
DERIVATIVE_FAK_TIF = "8"
DERIVATIVE_ORDER_STATE1 = "1"
DERIVATIVE_ORDER_STATE2 = "2"
DERIVATIVE_ORDER_STATE3 = "3"
DERIVATIVE_ORDER_STATE4 = "4"
DERIVATIVE_ORDER_STATE5 = "5"
DERIVATIVE_ORDER_STATE6 = "6"
DERIVATIVE_ORDER_STATE7 = "7"
DERIVATIVE_ORDER_STATE8 = "8"
DERIVATIVE_ORDER_STATE9 = "9"
DERIVATIVE_ORDER_STATEA = "A"
DERIVATIVE_IS_SIMULATED_USER = "1"
DERIVATIVE_IS_NOT_SIMULATED_USER = "0"
DERIVATIVE_ORDER_IS_NOT_CANCELLED = "0"
DERIVATIVE_ORDER_IS_CANCELLED = "1"
DERIVATIVE_POSITION_TYPE_Y = "0"
DERIVATIVE_POSITION_TYPE_T = "1"
STOCK_POSITION_FLAG_LONG = "1"
STOCK_POSITION_FLAG_SHORT = "2"
STOCK_BID = "1"
STOCK_ASK = "2"
STOCK_OPEN_POS_FLAG = "1"
STOCK_CLOSE_POS_FLAG = "2"
STOCK_LIMIT_ORDER = "1"
STOCK_MARKET_ORDER = "2"
STOCK_LIMIT_STOP_ORDER = "3"
STOCK_STOP_LOSS_ORDER = "4"
STOCK_TDY_TIF = "1"
STOCK_GTC_TIF = "2"
STOCK_OPG_TIF = "3"
STOCK_IOC_TIF = "4"
STOCK_FOK_TIF = "5"
STOCK_GTD_TIF = "6"
STOCK_ATC_TIF = "7"
STOCK_FAK_TIF = "8"
STOCK_ORDER_STATE1 = "1"
STOCK_ORDER_STATE2 = "2"
STOCK_ORDER_STATE3 = "3"
STOCK_ORDER_STATE4 = "4"
STOCK_ORDER_STATE5 = "5"
STOCK_ORDER_STATE6 = "6"
STOCK_ORDER_STATE7 = "7"
STOCK_ORDER_STATE8 = "8"
STOCK_ORDER_STATE9 = "9"
STOCK_ORDER_STATEA = "A"
STOCK_IS_SIMULATED_USER = "1"
STOCK_IS_NOT_SIMULATED_USER = "0"
